================================================================
sphinx-icalendar — iCalendar code blocks for Sphinx docs
================================================================

The `sphinx-icalendar <https://pypi.org/project/sphinx-icalendar/>`_ package
is a Sphinx extension that renders ``.. code-block:: calendar`` directives as
interactive HTML tables.  It turns :rfc:`5545` iCalendar (ICS) or
:rfc:`7265` jCal (JSON) input into
tabs with a rendered event table and the source specification.

----

:Homepage: https://sphinx-icalendar.readthedocs.io/en/latest/
:Issue Tracker: https://github.com/niccokunzmann/sphinx-icalendar-extension/issues
:Code: https://github.com/niccokunzmann/sphinx-icalendar-extension
:Dependencies: `icalendar <https://pypi.org/project/icalendar/>`_,
               `recurring-ical-events <https://pypi.org/project/recurring-ical-events/>`_,
               `sphinx-design <https://pypi.org/project/sphinx-design/>`_
:License: `GPL-3.0-or-later <https://github.com/niccokunzmann/sphinx-icalendar-extension/blob/main/LICENSE>`_

----

.. image:: https://img.shields.io/pypi/v/sphinx-icalendar
    :target: https://pypi.org/project/sphinx-icalendar/
    :alt: Python package version on PyPI

.. image:: https://img.shields.io/pypi/pyversions/sphinx-icalendar
    :target: https://pypi.org/project/sphinx-icalendar/
    :alt: Supported Python versions

.. image:: https://img.shields.io/github/actions/workflow/status/niccokunzmann/sphinx-icalendar-extension/tests.yml?branch=main&label=main&logo=github
    :target: https://github.com/niccokunzmann/sphinx-icalendar-extension/actions/workflows/tests.yml
    :alt: GitHub Actions build status

.. image:: https://readthedocs.org/projects/sphinx-icalendar/badge/?version=latest
    :target: https://sphinx-icalendar.readthedocs.io/en/latest/
    :alt: Documentation status

.. image:: https://img.shields.io/github/stars/niccokunzmann/sphinx-icalendar-extension?style=social
    :target: https://github.com/niccokunzmann/sphinx-icalendar-extension
    :alt: GitHub stars

.. image:: https://img.shields.io/github/sponsors/niccokunzmann?label=Sponsor&logo=GitHub
    :target: https://github.com/sponsors/niccokunzmann
    :alt: GitHub Sponsors